@@ -1,3 +1,4 @@
+
 package AxKit::App::TABOO::Data;
 use strict;
 use warnings;
@@ -8,9 +9,6 @@ use Class::Data::Inheritable;
 use base qw(Class::Data::Inheritable);
 
 
-our $VERSION = '0.021_2';
-
-
 use DBI;
 use Exception::Class::DBI;
 
@@ -49,9 +47,7 @@ sub new {
     my $username = shift;
     my $class = ref($that) || $that;
     my $self = {
-		ONFILE => undef,
-		XMLELEMENT => 'taboo',
-		XMLNS => 'http://www.kjetil.kjernsmo.net/software/TABOO/NS/Output'
+		XMLELEMENT => 'taboo'
 	       };
 
     bless($self, $class);
@@ -78,9 +74,6 @@ sub load {
     my $sth = $dbh->prepare($self->selectquery());
     $sth->execute($dbkey);
     my $data = $sth->fetchrow_hashref;
-    if ($data) {
-      ${$self}{'ONFILE'} = 1;
-    }
     foreach my $key (keys(%{$data})) {
       ${$self}{$key} = ${$data}{$key}; 
     }
@@ -100,13 +93,13 @@ sub write_xml {
     my $self = shift;
     my $doc = shift;
     my $parent = shift;
-    my $topel = $doc->createElementNS($self->xmlns(), $self->xmlelement());
+    my $topel = $doc->createElement($self->xmlelement());
     $parent->appendChild($topel);
     foreach my $key (split(/,\s*/, $self->elementorder())) {
       if (defined(${$self}{$key})) {
 	my $content = ${$self}{$key};
 	if (ref($content) eq '') {
-	  my $element = $doc->createElementNS($self->xmlns(), $key);
+	  my $element = $doc->createElement($key);
 	  my $text = XML::LibXML::Text->new($content);
 	  $element->appendChild($text);
 	  $topel->appendChild($element);
@@ -114,7 +107,7 @@ sub write_xml {
 	  # The content is an array, we must go through it and add an element for each.
 	  foreach (@{$content}) {
 	    if (ref($_) eq '') {
-	      my $element = $doc->createElementNS($self->xmlns(), $key);
+	      my $element = $doc->createElement($key);
 	      my $text = XML::LibXML::Text->new($_);
 	      $element->appendChild($text);
 	      $topel->appendChild($element);
@@ -130,7 +123,7 @@ sub write_xml {
 	  # a reference to one of our subclasses, it must be written too. 
 	  ${$content}->write_xml($doc, $topel);
         } else {
-	  my $element = $doc->createElementNS($self->xmlns(), $key);
+	  my $element = $doc->createElement($key);
 	  my $text = XML::LibXML::Text->new($content);
 	  $element->appendChild($text);
 	  $topel->appendChild($element);
@@ -176,9 +169,9 @@ It is not yet a very rigorous implementation: It may well fail badly if it is gi
 sub save {
   my $self = shift;
   my $olddbkey = shift;
-  my $dbh = DBI->connect($self->dbstring(),
-			 $self->dbuser(),
-			 $self->dbpasswd());
+  my $dbh = DBI->connect($self->dbstring(), 
+			 $self->dbuser(), 
+			 $self->dbpasswd());  
 #			 { PrintError => 1,
 #			   RaiseError => 0,
 #			   HandleError => Exception::Class::DBI->handler
@@ -254,7 +247,7 @@ sub stored {
   
 =item C<xmlelement($string)>
 
-This method is I<intended> for internal use, but if you can use it without shooting somebody in the foot (including yourself), fine by me... It sets the root element that will enclose an object's data to C<$string>.
+This method is I<intended> for internal use, but if you can use it without shooting somebody in the foot (including yourself), fine by me... It sets the parent element of an object to C<$string>.
 
 =cut
 
@@ -268,22 +261,6 @@ sub xmlelement {
   return ${$self}{'XMLELEMENT'};
 }
 
-=item C<xmlns($string)>
-
-Like  C<xmlelement()>, this method is I<intended> for internal use. It sets the namespace URI of the XML representation of an object to C<$string>.
-
-=cut
-
-
-
-sub xmlns {
-  my $self = shift;
-  if (@_) { 
-    ${$self}{'XMLNS'} = shift;
-  }
-  return ${$self}{'XMLNS'};
-}
-
 
 
 =item C<_addinfo($add, $this, $that)>
