@@ -13,9 +13,6 @@ use vars qw/@ISA/;
 use DBI;
 
 
-our $VERSION = '0.021_2';
-
-
 
 =head1 NAME
 
@@ -62,9 +59,6 @@ sub new {
 	USER => undef,
 	REPLIES => [],
 	XMLELEMENT => 'reply',
-	XMLNS => 'http://www.kjetil.kjernsmo.net/software/TABOO/NS/Comment/Output',
-	ONFILE => undef,
-
     };
     bless($self, $class);
     return $self;
@@ -108,9 +102,6 @@ sub load {
     my $sth = $dbh->prepare("SELECT $what FROM comments WHERE commentpath=? AND sectionid=? AND storyname=?");
     $sth->execute($commentpath, $section, $storyname);
     my $data = $sth->fetchrow_hashref;
-    if ($data) {
-      ${$self}{'ONFILE'} = 1;
-    }
     # Here, data will contain the basic data from the database
     # We are interested in the replies as well. Therefore, we retrieve the 
     # commentpaths by selecting the commentpaths that start with the 
@@ -238,19 +229,6 @@ These are the names of the stored data of this class:
 =back
 
 
-=head1 XML representation
-
-The C<write_xml()> method, implemented in the parent class, can be used to create an XML representation of the data in the object. The above names will be used as element names. The C<xmlelement()> and C<xmlns()> methods can be used to set the name of the root element and the namespace respectively. Usually, it doesn't make sense to change the defaults, which are 
-
-
-=over
-
-=item * C<reply>
-
-=item * C<http://www.kjetil.kjernsmo.net/software/TABOO/NS/Comment/Output>
- 
-=back
-
 =head1 FORMALITIES
 
 See L<AxKit::App::TABOO>.
