@@ -15,8 +15,6 @@ use XML::LibXML;
 use vars qw/$NS/;
 
 
-our $VERSION = '0.021_2';
-
 
 =head1 NAME
 
@@ -73,7 +71,7 @@ sub get_categories : struct attribOrChild(type) {
     my $tmp = AxKit::App::TABOO::Data::Category->new();
     my $cats = $tmp->all_of_type($attr_type);
     my $doc = XML::LibXML::Document->new();
-    my $root = $doc->createElementNS('http://www.kjetil.kjernsmo.net/software/TABOO/NS/Category/Output', 'categories');
+    my $root = $doc->createElement('categories');
     $root->setAttribute('type', $attr_type);
     $doc->setDocumentElement($root);
     foreach my $catname (@{$cats}) {
